%global srcname kissfft
%global srcver 131

%global build_types %{?build_types} float
%global build_types %{?build_types} double
%global build_types %{?build_types} int16_t
%global build_types %{?build_types} int32_t
%global build_types %{?build_types} simd

Summary:        A Fast Fourier Transform (FFT) library that tries to Keep it Simple, Stupid
Name:           kiss-fft
License:        BSD-3-Clause

Version:        %{srcver}.1.0
Release:    1%{?dist}

URL:            https://github.com/mborgerding/%{srcname}
Source0:        %{url}/archive/%{version}/%{srcname}-%{version}.tar.gz

BuildRequires:  cmake

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libpng-devel
BuildRequires:  python3
BuildRequires:  cmake >= 2.8.5	
BuildRequires:  fftw-devel
BuildRequires:  python3-numpy

%description
KISS FFT - A mixed-radix Fast Fourier Transform based on the 
principle, "Keep It Simple, Stupid."

There are many great fft libraries already around. Kiss FFT is
not trying to be better than any of them. It only attempts to be
a reasonably efficient, moderately useful FFT that can use fixed
or floating data types and can be incorporated into someone's C
program in a few minutes with trivial licensing.

%package static
Summary:        A Fast Fourier Transform (FFT) library that tries to Keep it Simple, Stupid
Requires:       %{name}-devel = %{version}-%{release}

%description static
Static libraries for KISS FFT - A mixed-radix Fast Fourier Transform based 
on the principle, "Keep It Simple, Stupid."

%package devel
Summary:        A Fast Fourier Transform (FFT) library that tries to Keep it Simple, Stupid
Requires:       %{name} = %{version}-%{release}

%description devel
Dynamically linked libraries and header files for KISS FFT - A mixed-radix Fast 
Fourier Transform based on the principle, "Keep It Simple, Stupid."

There are many great fft libraries already around. Kiss FFT is
not trying to be better than any of them. It only attempts to be
a reasonably efficient, moderately useful FFT that can use fixed
or floating data types and can be incorporated into someone's C
program in a few minutes with trivial licensing.

%prep
%autosetup -n %{srcname}-%{version}

%build
%{set_build_flags}

for build_type in %{build_types}; do
  mkdir ${build_type}-dynamic
  cd ${build_type}-dynamic
  %cmake .. -DKISSFFT_DATATYPE=${build_type} -DKISSFFT_TEST=ON -DKISSFFT_TOOLS=ON \
  -DKISSFFT_STATIC=OFF -DBUILD_SHARED_LIBS=ON
  %cmake_build
  cd ..
  mkdir ${build_type}-static
  cd ${build_type}-static
  %cmake .. -DKISSFFT_DATATYPE=${build_type} -DKISSFFT_TEST=ON -DKISSFFT_TOOLS=ON \
  -DKISSFFT_STATIC=ON -DBUILD_SHARED_LIBS=OFF
  %cmake_build
  cd ..
done

%install
for build_type in %{build_types}; do
  cd ${build_type}-dynamic
  %cmake_install
  cd ..
  cd ${build_type}-static
  %cmake_install
  cd ..
done

%check
for build_type in %{build_types}; do
  cd ${build_type}-dynamic
  %ctest
  cd ..
  cd ${build_type}-static
  %ctest
  cd ..
done

%files
%doc README.md README.simd TIPS
%license COPYING LICENSES/BSD-3-Clause
%{_libdir}/libkissfft-int16_t.so.%{srcver}*
%{_libdir}/libkissfft-int32_t.so.%{srcver}*
%{_libdir}/libkissfft-float.so.%{srcver}*
%{_libdir}/libkissfft-double.so.%{srcver}*
%{_libdir}/libkissfft-simd.so.%{srcver}*
%{_bindir}/fastconv-int16_t
%{_bindir}/fastconvr-int16_t
%{_bindir}/fft-int16_t
%{_bindir}/psdpng-int16_t
%{_bindir}/fastconv-int32_t
%{_bindir}/fastconvr-int32_t
%{_bindir}/fft-int32_t
%{_bindir}/psdpng-int32_t
%{_bindir}/fastconv-float
%{_bindir}/fastconvr-float
%{_bindir}/fft-float
%{_bindir}/psdpng-float
%{_bindir}/fastconv-double
%{_bindir}/fastconvr-double
%{_bindir}/fft-double
%{_bindir}/psdpng-double
%{_bindir}/fastconv-simd
%{_bindir}/fastconvr-simd
%{_bindir}/fft-simd

%files static
%{_libdir}/libkissfft-int16_t.a
%{_libdir}/libkissfft-int32_t.a
%{_libdir}/libkissfft-float.a
%{_libdir}/libkissfft-double.a
%{_libdir}/libkissfft-simd.a

%files devel
%{_includedir}/%{srcname}
%{_libdir}/libkissfft-int16_t.so
%{_libdir}/libkissfft-int32_t.so
%{_libdir}/libkissfft-float.so
%{_libdir}/libkissfft-double.so
%{_libdir}/libkissfft-simd.so
%{_libdir}/cmake/%{srcname}
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Aug 20 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 131.1.0-1
- initial build
